@@ -28,7 +28,9 @@ from dateutil import parser as dateparser
 from nazca.utils.distances import (levenshtein, soundex, soundexcode,
                                    difflib_match,
                                    jaccard, euclidean, geographical,
-                                   LevenshteinProcessing, SoundexProcessing)
+                                   ExactMatchProcessing, GeographicalProcessing,
+                                   LevenshteinProcessing, SoundexProcessing,
+                                   JaccardProcessing, DifflibProcessing, TemporalProcessing)
 
 
 class DistancesTest(unittest.TestCase):
@@ -131,10 +133,48 @@ class DistancesTest(unittest.TestCase):
         paris = (48.856578, 2.351828)
         london = (51.504872, -0.07857)
         dist_parislondon = geographical(paris, london, in_radians=False)
-
         self.assertAlmostEqual(dist_parislondon, 341564, 0)
 
 
+class GeographicalTestCase(unittest.TestCase):
+
+    def test_geographical(self):
+        # Use the whole record
+        processing = GeographicalProcessing(units='km')
+        _input = ((48.856578, 2.351828), (51.504872, -0.07857))
+        pdist = processing.pdist(_input)
+        self.assertEqual([341.56415945105], pdist)
+
+    def test_geographical_2(self):
+        # Use a single column of the record (tuple version)
+        processing = GeographicalProcessing(ref_attr_index=1,
+                                            target_attr_index=1,
+                                            units='km')
+        _input = (('paris', (48.856578, 2.351828)),
+                  ('london', (51.504872, -0.07857)))
+        pdist = processing.pdist(_input)
+        self.assertEqual([341.56415945105], pdist)
+
+    def test_geographical_3(self):
+        # Use two columns of the record
+        processing = GeographicalProcessing(ref_attr_index=(1,2),
+                                            target_attr_index=(1,2),
+                                            units='km')
+        _input = (('paris', 48.856578, 2.351828),
+                  ('london', 51.504872, -0.07857))
+        pdist = processing.pdist(_input)
+        self.assertEqual([341.56415945105], pdist)
+
+
+class ExactMatchTestCase(unittest.TestCase):
+
+    def test_pdist(self):
+        processing = ExactMatchProcessing()
+        _input = ['Victor Hugo', 'Victo Hugo', 'Victor Hugo']
+        pdist = processing.pdist(_input)
+        self.assertEqual([1, 0., 1], pdist)
+
+
 class LevenshteinTestCase(unittest.TestCase):
 
     def setUp(self):
@@ -176,6 +216,37 @@ class SoundexTestCase(unittest.TestCase):
         self.assertEqual([0, 1, 1], pdist)
 
 
+class JaccardTestCase(unittest.TestCase):
+
+    def test_pdist(self):
+        processing = JaccardProcessing()
+        _input = [u'Robert Ugo', u'Rubert Ugo', 'Rubert Pugo']
+        pdist = processing.pdist(_input)
+        results = [0.666, 1, 0.666]
+        for ind, value in enumerate(pdist):
+            self.assertAlmostEqual(results[ind], value, 2)
+
+
+class DifflibTestCase(unittest.TestCase):
+
+    def test_pdist(self):
+        processing = DifflibProcessing()
+        _input = [u'Robert Ugo', u'Rubert Ugo', 'Rubert Pugo']
+        pdist = processing.pdist(_input)
+        results = [0.099, 0.238, 0.14]
+        for ind, value in enumerate(pdist):
+            self.assertAlmostEqual(results[ind], value, 2)
+
+
+class TemporalTestCase(unittest.TestCase):
+
+    def test_pdist(self):
+        processing = TemporalProcessing()
+        _input = ['14 aout 1991', '08/14/1991', '08/15/1992']
+        pdist = processing.pdist(_input)
+        self.assertEqual([0., 367, 367], pdist)
+
+
 if __name__ == '__main__':
     unittest.main()
 
