@@ -117,6 +117,11 @@ def euclidean(a, b):
 ###############################################################################
 ### STRING DISTANCES ##########################################################
 ###############################################################################
+def exact_match(a, b):
+    """ The simplest distance, defined as 0 if both values are equal, 1 elsewise.
+    """
+    return 0 if a==b else 1
+
 def levenshtein(stra, strb, tokenizer=None):
     """ Compute the Levenshtein distance between stra and strb.
 
@@ -318,6 +323,8 @@ def geographical(pointa, pointb, in_radians=False, planet_radius=6371009,
 
         - `units` can be 'm' (meters) or 'km' (kilometers)
     """
+    if units not in ('m', 'km'):
+        raise ValueError("unsupported units, should be in m or km")
     pointa = (float(pointa[0]), float(pointa[1]))
     pointb = (float(pointb[0]), float(pointb[1]))
 
@@ -374,6 +381,14 @@ class BaseProcessing(object):
         self.weight = weight
         self.matrix_normalized = matrix_normalized
 
+    def build_record(self, record, index):
+        """ Allow to have ref_attr_index and target_attr_index to be couple
+        of index for (latitude, longitude) """
+        if isinstance(index, tuple) and len(index) == 2:
+            return (record[index[0]], record[index[1]])
+        else:
+            return (record[index] if index else record)
+
     def distance(self, reference_record, target_record):
         """ Compute the distance between two records
 
@@ -384,11 +399,8 @@ class BaseProcessing(object):
         target_record: a record (tuple/list of values) of the target dataset.
 
         """
-        refrecord = (reference_record[self.ref_attr_index] if self.ref_attr_index
-                     else reference_record)
-        targetrecord = (target_record[self.target_attr_index] if self.target_attr_index
-                        else target_record)
-        return self.distance_callback(refrecord, targetrecord)
+        return self.distance_callback(self.build_record(reference_record, self.ref_attr_index),
+                                      self.build_record(target_record, self.target_attr_index))
 
     def cdist(self, refset, targetset, ref_indexes=None, target_indexes=None):
         """ Compute the metric matrix, given two datasets and a metric
@@ -439,6 +451,17 @@ class BaseProcessing(object):
 ###############################################################################
 ### CONCRETE PROCESSINGS #######################################################
 ###############################################################################
+class ExactMatchProcessing(BaseProcessing):
+    """ A processing based on the exact match (1 if a==b, 0 elsewise)
+    """
+
+    def __init__(self, ref_attr_index=None, target_attr_index=None,
+                 tokenizer=None, weight=1, matrix_normalized=False):
+        super(ExactMatchProcessing, self).__init__(ref_attr_index,
+                                                   target_attr_index,
+                                                   exact_match,
+                                                   weight, matrix_normalized)
+
 class LevenshteinProcessing(BaseProcessing):
     """ A processing based on the levenshtein distance.
     """
@@ -466,6 +489,7 @@ class GeographicalProcessing(BaseProcessing):
                                                     distance_callback,
                                                     weight, matrix_normalized)
 
+
 class SoundexProcessing(BaseProcessing):
     """ A processing based on the soundex distance.
     """
@@ -477,3 +501,45 @@ class SoundexProcessing(BaseProcessing):
                                                 target_attr_index,
                                                 distance_callback,
                                                 weight, matrix_normalized)
+
+
+class JaccardProcessing(BaseProcessing):
+    """ A processing based on the jaccard distance.
+    """
+
+    def __init__(self, ref_attr_index=None, target_attr_index=None,
+                 tokenizer=None, weight=1, matrix_normalized=False):
+        distance_callback = partial(jaccard, tokenizer=tokenizer)
+        super(JaccardProcessing, self).__init__(ref_attr_index,
+                                                target_attr_index,
+                                                distance_callback,
+                                                weight, matrix_normalized)
+
+
+class DifflibProcessing(BaseProcessing):
+    """ A processing based on the difflib distance.
+    """
+
+    def __init__(self, ref_attr_index=None, target_attr_index=None,
+                 weight=1, matrix_normalized=False):
+        super(DifflibProcessing, self).__init__(ref_attr_index,
+                                                target_attr_index,
+                                                difflib_match,
+                                                weight, matrix_normalized)
+
+
+class TemporalProcessing(BaseProcessing):
+    """ A processing based on the temporal distance.
+    """
+
+    def __init__(self, ref_attr_index=None, target_attr_index=None,
+                 granularity=u'days', parserinfo=FrenchParserInfo,
+                 dayfirst=True, yearfirst=False,
+                 weight=1, matrix_normalized=False):
+        distance_callback = partial(temporal, granularity=granularity,
+                                    parserinfo=parserinfo,
+                                    dayfirst=dayfirst, yearfirst=yearfirst)
+        super(TemporalProcessing, self).__init__(ref_attr_index,
+                                                target_attr_index,
+                                                distance_callback,
+                                                weight, matrix_normalized)
